@@ -15,7 +15,6 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List, Type, overload
 
-from boto3.botocore_stubs import ClientError as BotocoreClientError
 from botocore.client import ClientMeta
 
 from mypy_boto3_docdb.paginator import (
@@ -85,6 +84,14 @@ else:
 __all__ = ("DocDBClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
     AuthorizationNotFoundFault: Type[BotocoreClientError]
     CertificateNotFoundFault: Type[BotocoreClientError]
